{{ ansible_managed | comment }}
{{ "performancecopilot:ansible-pcp" | comment(prefix="", postfix="") }}
[connection]
driver={ODBC Driver 17 for SQL Server}
server=tcp:localhost
timeout={{ mssql_agent_timeout }}

[authentication]
## General reference on authentication options:
#https://docs.microsoft.com/en-us/sql/relational-databases/security/choose-an-authentication-mode

# Option 1: Mixed mode authentication
username={{ mssql_agent_username }}
password={{ mssql_agent_password }}

# Option 2: Windows authentication
trusted={{ mssql_agent_trusted }}
