{{ ansible_managed | comment }}
{{ "performancecopilot:ansible-pcp" | comment(prefix="", postfix="") }}
[pmda]
user = pcp
baseurl = http://localhost:{{ elasticsearch_agent_port }}/
auth = {{ elasticsearch_agent_authname }}
password = {{ elasticsearch_agent_password }}
